@@ -35,9 +35,9 @@ sub _create {
 sub _delGroupWarning($$) {
         my $self = shift;
         my $group = shift;
-	
+
 	my $users = EBox::Global->modInstance('users');
-	
+
 	unless ($users->_groupIsEmpty($group)) {
 		return (__('This group contains users'));
 	}
@@ -45,4 +45,22 @@ sub _delGroupWarning($$) {
 	return undef;
 }
 
+sub schemas
+{
+    return [
+        EBox::Config::share() . '/ebox-usersandgroups/passwords.ldif',
+        EBox::Config::share() . '/ebox-usersandgroups/master.ldif',
+        EBox::Config::share() . '/ebox-usersandgroups/slaves.ldif'
+    ];
+}
+
+sub acls
+{
+    my $users = EBox::Global->modInstance('users');
+    return [ "to attrs=" . join(',',
+            @{EBox::UsersAndGroups::Passwords::allPasswordFieldNames()}) . " " .
+            "by dn=\"" . $users->ldap()->rootDn() . "\" write by self write " .
+            "by * none" ];
+}
+
 1;
